@@ -11,9 +11,12 @@ from dagster import (
     dagster_type_loader,
     dagster_type_materializer,
 )
+from dagster.check import CheckError
 from dagster.config.field_utils import Selector
+from dagster.core.definitions.event_metadata import parse_metadata
+from dagster.core.errors import DagsterInvalidEventMetadata
 from dagster.utils import dict_without_keys
-from dagster.utils.backcompat import canonicalize_backcompat_args, experimental
+from dagster.utils.backcompat import experimental
 from dagster_pandas.constraints import (
     ColumnDTypeFnConstraint,
     ColumnDTypeInSetConstraint,
@@ -158,8 +161,6 @@ def create_dagster_pandas_dataframe_type(
     dataframe_constraints=None,
     loader=None,
     materializer=None,
-    input_hydration_config=None,
-    output_materialization_config=None,
 ):
     """
     Constructs a custom pandas dataframe dagster type.
@@ -169,8 +170,9 @@ def create_dagster_pandas_dataframe_type(
         description (Optional[str]): A markdown-formatted string, displayed in tooling.
         columns (Optional[List[PandasColumn]]): A list of :py:class:`~dagster.PandasColumn` objects
             which express dataframe column schemas and constraints.
-        event_metadata_fn (Optional[func]): A callable which takes your dataframe and returns a list of EventMetadata
-            which allow you to express things like summary statistics during runtime.
+        event_metadata_fn (Optional[Callable[[], Union[Dict[str, Union[str, float, int, Dict, EventMetadata]], List[EventMetadataEntry]]]]):
+            A callable which takes your dataframe and returns a dict with string label keys and
+            EventMetadata values. Can optionally return a List[EventMetadataEntry].
         dataframe_constraints (Optional[List[DataFrameConstraint]]): A list of objects that inherit from
             :py:class:`~dagster.DataFrameConstraint`. This allows you to express dataframe-level constraints.
         loader (Optional[DagsterTypeLoader]): An instance of a class that
@@ -181,7 +183,7 @@ def create_dagster_pandas_dataframe_type(
             default to using `dataframe_materializer`.
     """
     # We allow for the plugging in of dagster_type_loaders/materializers so that
-    # Users can load and matrerialize their custom dataframes via configuration their own way if the default
+    # Users can load and materialize their custom dataframes via configuration their own way if the default
     # configs don't suffice. This is purely optional.
     check.str_param(name, "name")
     event_metadata_fn = check.opt_callable_param(event_metadata_fn, "event_metadata_fn")
@@ -213,22 +215,11 @@ def create_dagster_pandas_dataframe_type(
             else None,
         )
 
-    loader_ = canonicalize_backcompat_args(
-        loader, "loader", input_hydration_config, "input_hydration_config", "0.10.0",
-    )
-    materializer_ = canonicalize_backcompat_args(
-        materializer,
-        "materializer",
-        output_materialization_config,
-        "output_materialization_config",
-        "0.10.0",
-    )
-
     return DagsterType(
         name=name,
         type_check_fn=_dagster_type_check,
-        loader=loader_ if loader_ else dataframe_loader,
-        materializer=materializer_ if materializer_ else dataframe_materializer,
+        loader=loader if loader else dataframe_loader,
+        materializer=materializer if materializer else dataframe_materializer,
         description=description,
     )
 
@@ -242,8 +233,6 @@ def create_structured_dataframe_type(
     dataframe_validator=None,
     loader=None,
     materializer=None,
-    input_hydration_config=None,
-    output_materialization_config=None,
 ):
     """
 
@@ -303,7 +292,10 @@ def create_structured_dataframe_type(
             typechecks_succeeded = typechecks_succeeded and result_val
             result_dict = result.metadata_entries[0].entry_data.data
             metadata.append(
-                EventMetadataEntry.json(result_dict, "{}-constraint-metadata".format(key),)
+                EventMetadataEntry.json(
+                    result_dict,
+                    "{}-constraint-metadata".format(key),
+                )
             )
             constraint_clauses.append("{} failing constraints, {}".format(key, result.description))
         # returns aggregates, then column, then dataframe
@@ -314,21 +306,11 @@ def create_structured_dataframe_type(
         )
 
     description = check.opt_str_param(description, "description", default="")
-    loader_ = canonicalize_backcompat_args(
-        loader, "loader", input_hydration_config, "input_hydration_config", "0.10.0",
-    )
-    materializer_ = canonicalize_backcompat_args(
-        materializer,
-        "materializer",
-        output_materialization_config,
-        "output_materialization_config",
-        "0.10.0",
-    )
     return DagsterType(
         name=name,
         type_check_fn=_dagster_type_check,
-        loader=loader_ if loader_ else dataframe_loader,
-        materializer=materializer_ if materializer_ else dataframe_materializer,
+        loader=loader if loader else dataframe_loader,
+        materializer=materializer if loader else dataframe_materializer,
         description=description,
     )
 
@@ -337,18 +319,25 @@ def _execute_summary_stats(type_name, value, event_metadata_fn):
     if not event_metadata_fn:
         return []
 
-    metadata_entries = event_metadata_fn(value)
+    metadata_or_metadata_entries = event_metadata_fn(value)
 
-    if not (
-        isinstance(metadata_entries, list)
-        and all(isinstance(item, EventMetadataEntry) for item in metadata_entries)
-    ):
-        raise DagsterInvariantViolationError(
-            (
-                "The return value of the user-defined summary_statistics function "
-                "for pandas data frame type {type_name} returned {value}. "
-                "This function must return List[EventMetadataEntry]"
-            ).format(type_name=type_name, value=repr(metadata_entries))
-        )
+    invalid_message = (
+        "The return value of the user-defined summary_statistics function for pandas "
+        f"data frame type {type_name} returned {value}. This function must return "
+        "Union[Dict[str, Union[str, float, int, Dict, EventMetadata]], List[EventMetadataEntry]]"
+    )
 
-    return metadata_entries
+    metadata = None
+    metadata_entries = None
+
+    if isinstance(metadata_or_metadata_entries, list):
+        metadata_entries = metadata_or_metadata_entries
+    elif isinstance(metadata_or_metadata_entries, dict):
+        metadata = metadata_or_metadata_entries
+    else:
+        raise DagsterInvariantViolationError(invalid_message)
+
+    try:
+        return parse_metadata(metadata, metadata_entries)
+    except (DagsterInvalidEventMetadata, CheckError):
+        raise DagsterInvariantViolationError(invalid_message)
